@@ -1,23 +1,23 @@
 #' Create Model Explainer
 #'
 #' Black-box models may have very different structures.
-#' This function creates a unified representation of a model, which can be further processed by various explainers.
+#' This function creates a unified representation of a model, which can be further processed by functions for explanations.
 #'
 #' Please NOTE, that the \code{model} is the only required argument.
-#' But some explainers may require that other arguments will be provided too.
+#' But some explanations may expect that other arguments will be provided too.
 #'
 #' @param model object - a model to be explained
-#' @param data data.frame or matrix - data that was used for fitting. If not provided then will be extracted from the model. Data should be passed without target column (this shall be provided as the \code{y} argument). NOTE: If target variable is present in the \code{data}, some of the functionalities my not work properly.
+#' @param data data.frame or matrix - data which will be used to calculate the explanations. If not provided then will be extracted from the model. Data should be passed without target column (this shall be provided as the \code{y} argument). NOTE: If target variable is present in the \code{data}, some of the functionalities my not work properly.
 #' @param y numeric vector with outputs / scores. If provided then it shall have the same size as \code{data}
 #' @param weights numeric vector with sampling weights. By default it's \code{NULL}. If provided then it shall have the same length as \code{data}
-#' @param predict_function function that takes two arguments: model and new data and returns numeric vector with predictions
-#' @param residual_function function that takes three arguments: model, data and response vector y. It should return a numeric vector with model residuals for given data. If not provided, response residuals (\eqn{y-\hat{y}}) are calculated.
+#' @param predict_function function that takes two arguments: model and new data and returns numeric vector with predictions.   By default it is \code{yhat}.
+#' @param residual_function function that takes four arguments: model, data, response vector y and predict function (optionally). It should return a numeric vector with model residuals for given data. If not provided, response residuals (\eqn{y-\hat{y}}) are calculated. By default it is \code{residual_function_default}.
 #' @param ... other parameters
 #' @param label character - the name of the model. By default it's extracted from the 'class' attribute of the model
-#' @param verbose if TRUE (default) then diagnostic messages will be printed
-#' @param precalculate if TRUE (default) then \code{predicted_values} and \code{residual} are calculated when explainer is created.
+#' @param verbose logical. If TRUE (default) then diagnostic messages will be printed
+#' @param precalculate logical. If TRUE (default) then \code{predicted_values} and \code{residual} are calculated when explainer is created.
 #' This will happen also if \code{verbose} is TRUE. Set both \code{verbose} and \code{precalculate} to FALSE to omit calculations.
-#' @param colorize if TRUE (default) then \code{WARNINGS}, \code{ERRORS} and \code{NOTES} are colorized. Will work only in the R console.
+#' @param colorize logical. If TRUE (default) then \code{WARNINGS}, \code{ERRORS} and \code{NOTES} are colorized. Will work only in the R console.
 #' @param model_info a named list (\code{package}, \code{version}, \code{type}) containg information about model. If \code{NULL}, \code{DALEX} will seek for information on it's own.
 #' @param type type of a model, either \code{classification} or \code{regression}. If not specified then \code{type} will be extracted from \code{model_info}.
 #'
@@ -199,19 +199,6 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
     }
   }
 
-  if (is.null(model_info)) {
-    # extract defaults
-    model_info <- model_info(model)
-    verbose_cat("  -> model_info        :  package", model_info$package[1], ", ver.", model_info$ver[1], ", task", model_info$type, "(", color_codes$yellow_start,"default",color_codes$yellow_end, ")", "\n", verbose = verbose)
-  } else {
-    verbose_cat("  -> model_info        :  package", model_info$package[1], ", ver.", model_info$ver[1], ", task", model_info$type, "\n", verbose = verbose)
-  }
-  # if type specified then it overwrite the type in model_info
-  if (!is.null(type)) {
-    model_info$type <- type
-    verbose_cat("  -> model_info        :  type set to ", type, "\n", verbose = verbose)
-  }
-
   # REPORT: checks for predict_function
   if (is.null(predict_function)) {
     # predict_function not specified
@@ -251,15 +238,30 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
     }
   }
 
+  if (is.null(model_info)) {
+    # extract defaults
+    task_subtype <- check_if_multilabel(model, predict_function, data[1:2,])
+    model_info <- model_info(model, is_multiclass = task_subtype)
+    verbose_cat("  -> model_info        :  package", model_info$package[1], ", ver.", model_info$ver[1], ", task", model_info$type, "(", color_codes$yellow_start,"default",color_codes$yellow_end, ")", "\n", verbose = verbose)
+  } else {
+    verbose_cat("  -> model_info        :  package", model_info$package[1], ", ver.", model_info$ver[1], ", task", model_info$type, "\n", verbose = verbose)
+  }
+  # if type specified then it overwrite the type in model_info
+  if (!is.null(type)) {
+    model_info$type <- type
+    verbose_cat("  -> model_info        :  type set to ", type, "\n", verbose = verbose)
+  }
+
   # REPORT: checks for residual_function
   if (is.null(residual_function)) {
     # residual_function not specified
     # try the default
-    if (!is.null(predict_function)) {
-      residual_function <- function(model, data, y) {
-        y - predict_function(model, data)
-      }
+    if (!is.null(predict_function) & model_info$type != "multiclass") {
+      residual_function <- residual_function_default
       verbose_cat("  -> residual function :  difference between y and yhat (",color_codes$yellow_start,"default",color_codes$yellow_end,")\n", verbose = verbose)
+    } else if (!is.null(predict_function) & model_info$type == "multiclass") {
+      residual_function <- residual_function_multiclass
+      verbose_cat("  -> residual function :  difference between 1 and probability of true class (",color_codes$yellow_start,"default",color_codes$yellow_end,")\n", verbose = verbose)
     }
   } else {
     if (!"function" %in% class(residual_function)) {
@@ -271,7 +273,7 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
   # if data is specified then we may test residual_function
   residuals <- NULL
   if (!is.null(data) && !is.null(residual_function) && !is.null(y) && (verbose | precalculate)) {
-    residuals <- try(residual_function(model, data, y), silent = TRUE)
+    residuals <- try(residual_function(model, data, y, predict_function), silent = TRUE)
     if (class(residuals)[1] == "try-error") {
       residuals <- NULL
       verbose_cat("  -> residuals         :  the residual_function returns an error when executed (",color_codes$red_start,"WARNING",color_codes$red_end,") \n", verbose = verbose)
@@ -317,6 +319,28 @@ is_y_in_data <- function(data, y) {
   }))
 }
 
+# check if model whether model is multilabel classification task
+check_if_multilabel <- function(model, predict_function, sample_data) {
+  response_sample <- try(predict_function(model, sample_data), silent = TRUE)
+  !is.null(dim(response_sample))
+}
+
+# default residual function
+residual_function_default <- function(model, data, y, predict_function = yhat) {
+  y - predict_function(model, data)
+}
+
+# default residual function for multiclass problems
+residual_function_multiclass <- function(model, data, y, predict_function = yhat) {
+  y_char <- as.character(y)
+  pred <- predict_function(model, data)
+  res <- numeric(nrow(pred))
+  for (i in 1:nrow(pred)) {
+    res[i] <- 1-pred[i, y_char[i]]
+  }
+  res
+}
+
 #' @rdname explain
 #' @export
 explain <- explain.default
